@@ -68,18 +68,20 @@ class Freebox(IPlugin):
 ##						for i in rs['idx_sec']:
 						if rs['idx'][bar] == '|':
 							log.msg(" bar  :  %s" % (bar))
-#>>> for rang in range(len(mot)):  # La variable rang parcourt les entiers de 0 au rang de la dernière lettre du mot.
-#...     if mot[rang] == 'i':
-#...         rangs.append(rang)    # Si la lettre du mot est 'i', on stocke le rang dans notre liste.
-#>>> rangs                         # On affiche le résultat.
-#[5, 7]
-##							# search position '|' dans rs['idx']	
-##							# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-##							for rx in rs['idx_sec']:
-##								log.msg(" rx  :  %s" % (rx))
-##								log.msg("idx_sec  :  %s" % rs['idx_sec'])
-##								log.msg("idx  :  %s" % (rs['idx']))
-##
+							ind1 = rs['idx'][:bar]
+							ind2 = rs['idx'][bar:]
+							log.msg(" ind1  :  %s" % (ind1))
+							log.msg(" ind2  :  %s" % (ind2))
+##>>> x[2:]
+##'llo World!'
+##>>> x[:2]
+##'He'
+##>>> x[:-2]
+##'Hello Worl'
+##>>> x[-2:]
+##'d!'
+##>>> x[2:-2]
+##'llo Worl'
 							resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 							log.msg("resp  :  %s" % (resp))
 				if rs['idx_sec'] == "1":
